@@ -1,13 +1,12 @@
 from django.contrib.auth.tokens import default_token_generator
 from django.contrib.auth import get_user_model
 
-from rest_framework import generics, permissions, status, response, views
+from rest_framework import generics, permissions, status, views
 from rest_framework.response import Response
 from rest_framework.reverse import reverse
 
 from . import serializers, settings, utils, signals
 
-
 User = get_user_model()
 
 
@@ -55,27 +54,28 @@ class RegistrationView(generics.CreateAPIView):
 
     def perform_create(self, serializer):
         user = serializer.save()
-        signals.user_registered.send(sender=self.__class__, user=user, request=self.request)
+        signals.user_registered.send(
+            sender=self.__class__, user=user, request=self.request
+        )
         if settings.get('SEND_ACTIVATION_EMAIL'):
             self.send_activation_email(user)
         elif settings.get('SEND_CONFIRMATION_EMAIL'):
             self.send_confirmation_email(user)
 
     def send_activation_email(self, user):
-        email_factory = utils.UserActivationEmailFactory.from_request(self.request, user=user)
+        email_factory = utils.UserActivationEmailFactory.from_request(
+            self.request, user=user
+        )
         email = email_factory.create()
         email.send()
 
     def send_confirmation_email(self, user):
-        email_factory = utils.UserConfirmationEmailFactory.from_request(self.request, user=user)
+        email_factory = utils.UserConfirmationEmailFactory.from_request(
+            self.request, user=user
+        )
         email = email_factory.create()
         email.send()
 
-    def get_email_context(self, user):
-        context = super(RegistrationView, self).get_email_context(user)
-        context['url'] = settings.get('ACTIVATION_URL').format(**context)
-        return context
-
 
 class LoginView(utils.ActionViewMixin, generics.GenericAPIView):
     """
@@ -105,7 +105,7 @@ class LogoutView(views.APIView):
 
     def post(self, request):
         utils.logout_user(request)
-        return response.Response(status=status.HTTP_204_NO_CONTENT)
+        return Response(status=status.HTTP_204_NO_CONTENT)
 
 
 class PasswordResetView(utils.ActionViewMixin, generics.GenericAPIView):
@@ -122,7 +122,7 @@ class PasswordResetView(utils.ActionViewMixin, generics.GenericAPIView):
     def _action(self, serializer):
         for user in self.get_users(serializer.data['email']):
             self.send_password_reset_email(user)
-        return response.Response(status=status.HTTP_204_NO_CONTENT)
+        return Response(status=status.HTTP_204_NO_CONTENT)
 
     def get_users(self, email):
         if self._users is None:
@@ -159,7 +159,7 @@ class SetPasswordView(utils.ActionViewMixin, generics.GenericAPIView):
         if settings.get('LOGOUT_ON_PASSWORD_CHANGE'):
             utils.logout_user(self.request)
 
-        return response.Response(status=status.HTTP_204_NO_CONTENT)
+        return Response(status=status.HTTP_204_NO_CONTENT)
 
 
 class PasswordResetConfirmView(utils.ActionViewMixin, generics.GenericAPIView):
@@ -179,7 +179,7 @@ class PasswordResetConfirmView(utils.ActionViewMixin, generics.GenericAPIView):
     def _action(self, serializer):
         serializer.user.set_password(serializer.data['new_password'])
         serializer.user.save()
-        return response.Response(status=status.HTTP_204_NO_CONTENT)
+        return Response(status=status.HTTP_204_NO_CONTENT)
 
 
 class ActivationView(utils.ActionViewMixin, generics.GenericAPIView):
@@ -221,7 +221,7 @@ class SetUsernameView(utils.ActionViewMixin, generics.GenericAPIView):
     def _action(self, serializer):
         setattr(self.request.user, User.USERNAME_FIELD, serializer.data['new_' + User.USERNAME_FIELD])
         self.request.user.save()
-        return response.Response(status=status.HTTP_204_NO_CONTENT)
+        return Response(status=status.HTTP_204_NO_CONTENT)
 
 
 class UserView(generics.RetrieveUpdateAPIView):
